# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/bellek',
                'doc_host': 'https://bdsaglam.github.io',
                'git_url': 'https://github.com/bdsaglam/bellek',
                'lib_path': 'bellek'},
  'syms': { 'bellek.logging': {'bellek.logging.get_logger': ('logging.html#get_logger', 'bellek/logging.py')},
            'bellek.ml.clip': { 'bellek.ml.clip.ClipClassificationHead': ('ml.clip.html#clipclassificationhead', 'bellek/ml/clip.py'),
                                'bellek.ml.clip.ClipClassificationHead.__init__': ( 'ml.clip.html#clipclassificationhead.__init__',
                                                                                    'bellek/ml/clip.py'),
                                'bellek.ml.clip.ClipClassificationHead.forward': ( 'ml.clip.html#clipclassificationhead.forward',
                                                                                   'bellek/ml/clip.py'),
                                'bellek.ml.clip.ClipZeroShotClassifier': ('ml.clip.html#clipzeroshotclassifier', 'bellek/ml/clip.py'),
                                'bellek.ml.clip.ClipZeroShotClassifier.__init__': ( 'ml.clip.html#clipzeroshotclassifier.__init__',
                                                                                    'bellek/ml/clip.py'),
                                'bellek.ml.clip.ClipZeroShotClassifier.compute_text_features': ( 'ml.clip.html#clipzeroshotclassifier.compute_text_features',
                                                                                                 'bellek/ml/clip.py'),
                                'bellek.ml.clip.ClipZeroShotClassifier.forward': ( 'ml.clip.html#clipzeroshotclassifier.forward',
                                                                                   'bellek/ml/clip.py'),
                                'bellek.ml.clip.load_clip_preprocess': ('ml.clip.html#load_clip_preprocess', 'bellek/ml/clip.py'),
                                'bellek.ml.clip.make_tfms_from_clip_preprocess': ( 'ml.clip.html#make_tfms_from_clip_preprocess',
                                                                                   'bellek/ml/clip.py')},
            'bellek.ml.coop': { 'bellek.ml.coop.ClipVisualEncoder': ('ml.coop.html#clipvisualencoder', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.ClipVisualEncoder.__init__': ( 'ml.coop.html#clipvisualencoder.__init__',
                                                                               'bellek/ml/coop.py'),
                                'bellek.ml.coop.ClipVisualEncoder.forward': ('ml.coop.html#clipvisualencoder.forward', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearner': ('ml.coop.html#promptlearner', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearner.__init__': ('ml.coop.html#promptlearner.__init__', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearner.forward': ('ml.coop.html#promptlearner.forward', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearningClip': ('ml.coop.html#promptlearningclip', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearningClip.__init__': ( 'ml.coop.html#promptlearningclip.__init__',
                                                                                'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearningClip.forward': ( 'ml.coop.html#promptlearningclip.forward',
                                                                               'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearningTextEncoder': ('ml.coop.html#promptlearningtextencoder', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearningTextEncoder.__init__': ( 'ml.coop.html#promptlearningtextencoder.__init__',
                                                                                       'bellek/ml/coop.py'),
                                'bellek.ml.coop.PromptLearningTextEncoder.forward': ( 'ml.coop.html#promptlearningtextencoder.forward',
                                                                                      'bellek/ml/coop.py'),
                                'bellek.ml.coop.TextEncoder': ('ml.coop.html#textencoder', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.TextEncoder.__init__': ('ml.coop.html#textencoder.__init__', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.TextEncoder.forward': ('ml.coop.html#textencoder.forward', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.make_prompt_learning_clip': ('ml.coop.html#make_prompt_learning_clip', 'bellek/ml/coop.py'),
                                'bellek.ml.coop.prepare_prompt_learning_clip': ( 'ml.coop.html#prepare_prompt_learning_clip',
                                                                                 'bellek/ml/coop.py')},
            'bellek.ml.data': { 'bellek.ml.data.ZippedDataLoader': ('ml.data.html#zippeddataloader', 'bellek/ml/data.py'),
                                'bellek.ml.data.ZippedDataLoader.__init__': ('ml.data.html#zippeddataloader.__init__', 'bellek/ml/data.py'),
                                'bellek.ml.data.ZippedDataLoader.__iter__': ('ml.data.html#zippeddataloader.__iter__', 'bellek/ml/data.py'),
                                'bellek.ml.data.ZippedDataLoader.__next__': ('ml.data.html#zippeddataloader.__next__', 'bellek/ml/data.py'),
                                'bellek.ml.data.ZippedDataset': ('ml.data.html#zippeddataset', 'bellek/ml/data.py'),
                                'bellek.ml.data.ZippedDataset.__getitem__': ('ml.data.html#zippeddataset.__getitem__', 'bellek/ml/data.py'),
                                'bellek.ml.data.ZippedDataset.__init__': ('ml.data.html#zippeddataset.__init__', 'bellek/ml/data.py'),
                                'bellek.ml.data.ZippedDataset.__len__': ('ml.data.html#zippeddataset.__len__', 'bellek/ml/data.py'),
                                'bellek.ml.data.fetch_imagenet_label_synsets': ( 'ml.data.html#fetch_imagenet_label_synsets',
                                                                                 'bellek/ml/data.py'),
                                'bellek.ml.data.get_imagenet_id_label_map': ('ml.data.html#get_imagenet_id_label_map', 'bellek/ml/data.py'),
                                'bellek.ml.data.get_imagenet_id_synset_map': ( 'ml.data.html#get_imagenet_id_synset_map',
                                                                               'bellek/ml/data.py'),
                                'bellek.ml.data.make_imagenet_id_synset_map': ( 'ml.data.html#make_imagenet_id_synset_map',
                                                                                'bellek/ml/data.py')},
            'bellek.ml.evaluation': { 'bellek.ml.evaluation.classification_summary': ( 'ml.evaluation.html#classification_summary',
                                                                                       'bellek/ml/evaluation.py'),
                                      'bellek.ml.evaluation.evaluate_slmc': ('ml.evaluation.html#evaluate_slmc', 'bellek/ml/evaluation.py'),
                                      'bellek.ml.evaluation.find_binary_clf_threshold': ( 'ml.evaluation.html#find_binary_clf_threshold',
                                                                                          'bellek/ml/evaluation.py')},
            'bellek.ml.experiment': { 'bellek.ml.experiment.main': ('ml.experiment.html#main', 'bellek/ml/experiment.py'),
                                      'bellek.ml.experiment.make_experiment_dir': ( 'ml.experiment.html#make_experiment_dir',
                                                                                    'bellek/ml/experiment.py'),
                                      'bellek.ml.experiment.make_run_experiment_sweep': ( 'ml.experiment.html#make_run_experiment_sweep',
                                                                                          'bellek/ml/experiment.py'),
                                      'bellek.ml.experiment.prepare_config': ( 'ml.experiment.html#prepare_config',
                                                                               'bellek/ml/experiment.py')},
            'bellek.ml.kg.cons': { 'bellek.ml.kg.cons.ERX2AlpacaFormatter': ('ml.kg.cons.html#erx2alpacaformatter', 'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2AlpacaFormatter.__post_init__': ( 'ml.kg.cons.html#erx2alpacaformatter.__post_init__',
                                                                                            'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2AlpacaFormatter._choose_few_shot_examples': ( 'ml.kg.cons.html#erx2alpacaformatter._choose_few_shot_examples',
                                                                                                        'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2AlpacaFormatter.format': ( 'ml.kg.cons.html#erx2alpacaformatter.format',
                                                                                     'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2AlpacaFormatter.make_system_prompt': ( 'ml.kg.cons.html#erx2alpacaformatter.make_system_prompt',
                                                                                                 'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2ChatFormatter': ('ml.kg.cons.html#erx2chatformatter', 'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2ChatFormatter.__post_init__': ( 'ml.kg.cons.html#erx2chatformatter.__post_init__',
                                                                                          'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2ChatFormatter._choose_few_shot_examples': ( 'ml.kg.cons.html#erx2chatformatter._choose_few_shot_examples',
                                                                                                      'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2ChatFormatter.format': ( 'ml.kg.cons.html#erx2chatformatter.format',
                                                                                   'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2ChatFormatter.make_messages': ( 'ml.kg.cons.html#erx2chatformatter.make_messages',
                                                                                          'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.ERX2ChatFormatter.make_system_message': ( 'ml.kg.cons.html#erx2chatformatter.make_system_message',
                                                                                                'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.evaluate_joint_er_extraction': ( 'ml.kg.cons.html#evaluate_joint_er_extraction',
                                                                                       'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.evaluate_joint_er_extractions': ( 'ml.kg.cons.html#evaluate_joint_er_extractions',
                                                                                        'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.evaluate_model_jer': ('ml.kg.cons.html#evaluate_model_jer', 'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.evaluate_pipe_jer': ('ml.kg.cons.html#evaluate_pipe_jer', 'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.format_few_shot_example': ( 'ml.kg.cons.html#format_few_shot_example',
                                                                                  'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.format_few_shot_examples': ( 'ml.kg.cons.html#format_few_shot_examples',
                                                                                   'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.format_triplets': ('ml.kg.cons.html#format_triplets', 'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.parse_triplet_strings': ( 'ml.kg.cons.html#parse_triplet_strings',
                                                                                'bellek/ml/kg/cons.py'),
                                   'bellek.ml.kg.cons.parse_triplets': ('ml.kg.cons.html#parse_triplets', 'bellek/ml/kg/cons.py')},
            'bellek.ml.kg.dataset': { 'bellek.ml.kg.dataset._batch_transform_webnlg': ( 'ml.kg.dataset.html#_batch_transform_webnlg',
                                                                                        'bellek/ml/kg/dataset.py'),
                                      'bellek.ml.kg.dataset._transform_entity': ( 'ml.kg.dataset.html#_transform_entity',
                                                                                  'bellek/ml/kg/dataset.py'),
                                      'bellek.ml.kg.dataset._transform_relation': ( 'ml.kg.dataset.html#_transform_relation',
                                                                                    'bellek/ml/kg/dataset.py'),
                                      'bellek.ml.kg.dataset._transform_triplet': ( 'ml.kg.dataset.html#_transform_triplet',
                                                                                   'bellek/ml/kg/dataset.py'),
                                      'bellek.ml.kg.dataset.batch_transform_webnlg': ( 'ml.kg.dataset.html#batch_transform_webnlg',
                                                                                       'bellek/ml/kg/dataset.py')},
            'bellek.ml.lang.dataset': { 'bellek.ml.lang.dataset.alpaca2openai': ( 'ml.lang.dataset.html#alpaca2openai',
                                                                                  'bellek/ml/lang/dataset.py'),
                                        'bellek.ml.lang.dataset.alpaca2sharegpt': ( 'ml.lang.dataset.html#alpaca2sharegpt',
                                                                                    'bellek/ml/lang/dataset.py'),
                                        'bellek.ml.lang.dataset.openai2sharegpt': ( 'ml.lang.dataset.html#openai2sharegpt',
                                                                                    'bellek/ml/lang/dataset.py'),
                                        'bellek.ml.lang.dataset.openai2sharegpt_message': ( 'ml.lang.dataset.html#openai2sharegpt_message',
                                                                                            'bellek/ml/lang/dataset.py'),
                                        'bellek.ml.lang.dataset.sharegpt2openai': ( 'ml.lang.dataset.html#sharegpt2openai',
                                                                                    'bellek/ml/lang/dataset.py'),
                                        'bellek.ml.lang.dataset.sharegpt2openai_message': ( 'ml.lang.dataset.html#sharegpt2openai_message',
                                                                                            'bellek/ml/lang/dataset.py')},
            'bellek.ml.layer': { 'bellek.ml.layer.GradReverse': ('ml.layer.html#gradreverse', 'bellek/ml/layer.py'),
                                 'bellek.ml.layer.GradReverse.__init__': ('ml.layer.html#gradreverse.__init__', 'bellek/ml/layer.py'),
                                 'bellek.ml.layer.GradReverse.forward': ('ml.layer.html#gradreverse.forward', 'bellek/ml/layer.py'),
                                 'bellek.ml.layer.reverse_grad': ('ml.layer.html#reverse_grad', 'bellek/ml/layer.py'),
                                 'bellek.ml.layer.reverse_grad.backward': ('ml.layer.html#reverse_grad.backward', 'bellek/ml/layer.py'),
                                 'bellek.ml.layer.reverse_grad.forward': ('ml.layer.html#reverse_grad.forward', 'bellek/ml/layer.py')},
            'bellek.ml.llama': { 'bellek.ml.llama.prepare_llama2_for_inference': ( 'ml.llama.html#prepare_llama2_for_inference',
                                                                                   'bellek/ml/llama.py'),
                                 'bellek.ml.llama.prepare_llama2_for_training': ( 'ml.llama.html#prepare_llama2_for_training',
                                                                                  'bellek/ml/llama.py')},
            'bellek.ml.llama_index': { 'bellek.ml.llama_index.HuggingFaceTextGenInferenceLLM': ( 'ml.llama_index.html#huggingfacetextgeninferencellm',
                                                                                                 'bellek/ml/llama_index.py')},
            'bellek.ml.llm.dataset': { 'bellek.ml.llm.dataset.alpaca2openai': ( 'ml.llm.dataset.html#alpaca2openai',
                                                                                'bellek/ml/llm/dataset.py'),
                                       'bellek.ml.llm.dataset.alpaca2sharegpt': ( 'ml.llm.dataset.html#alpaca2sharegpt',
                                                                                  'bellek/ml/llm/dataset.py'),
                                       'bellek.ml.llm.dataset.openai_role2sharegpt_from': ( 'ml.llm.dataset.html#openai_role2sharegpt_from',
                                                                                            'bellek/ml/llm/dataset.py'),
                                       'bellek.ml.llm.dataset.sharegpt2openai': ( 'ml.llm.dataset.html#sharegpt2openai',
                                                                                  'bellek/ml/llm/dataset.py'),
                                       'bellek.ml.llm.dataset.sharegpt_from2openai_role': ( 'ml.llm.dataset.html#sharegpt_from2openai_role',
                                                                                            'bellek/ml/llm/dataset.py')},
            'bellek.ml.loss': { 'bellek.ml.loss.BinaryFocalLoss': ('ml.loss.html#binaryfocalloss', 'bellek/ml/loss.py'),
                                'bellek.ml.loss.BinaryFocalLoss.__init__': ('ml.loss.html#binaryfocalloss.__init__', 'bellek/ml/loss.py'),
                                'bellek.ml.loss.BinaryFocalLoss.activation': ( 'ml.loss.html#binaryfocalloss.activation',
                                                                               'bellek/ml/loss.py'),
                                'bellek.ml.loss.BinaryFocalLoss.decodes': ('ml.loss.html#binaryfocalloss.decodes', 'bellek/ml/loss.py'),
                                'bellek.ml.loss.BinaryFocalLoss.forward': ('ml.loss.html#binaryfocalloss.forward', 'bellek/ml/loss.py')},
            'bellek.ml.mcd': { 'bellek.ml.mcd.DiscrepancyLoss': ('ml.mcd.html#discrepancyloss', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.DiscrepancyLoss.__call__': ('ml.mcd.html#discrepancyloss.__call__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.EnsembleMcdModel': ('ml.mcd.html#ensemblemcdmodel', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.EnsembleMcdModel.__init__': ('ml.mcd.html#ensemblemcdmodel.__init__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.EnsembleMcdModel.forward': ('ml.mcd.html#ensemblemcdmodel.forward', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.EnsembleMcdModel.from_mcd_model': ( 'ml.mcd.html#ensemblemcdmodel.from_mcd_model',
                                                                                  'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.Feature': ('ml.mcd.html#feature', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.Feature.__init__': ('ml.mcd.html#feature.__init__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.Feature.forward': ('ml.mcd.html#feature.forward', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback': ('ml.mcd.html#mcdcallback', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback.__init__': ('ml.mcd.html#mcdcallback.__init__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback._do_grad_opt': ('ml.mcd.html#mcdcallback._do_grad_opt', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback._do_one_batch': ('ml.mcd.html#mcdcallback._do_one_batch', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback._predict_source': ('ml.mcd.html#mcdcallback._predict_source', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback._predict_target': ('ml.mcd.html#mcdcallback._predict_target', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback.before_batch': ('ml.mcd.html#mcdcallback.before_batch', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdCallback.before_fit': ('ml.mcd.html#mcdcallback.before_fit', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataLoader': ('ml.mcd.html#mcddataloader', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataLoader.__init__': ('ml.mcd.html#mcddataloader.__init__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataLoader.__iter__': ('ml.mcd.html#mcddataloader.__iter__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataLoader.__len__': ('ml.mcd.html#mcddataloader.__len__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataLoader.__next__': ('ml.mcd.html#mcddataloader.__next__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataLoader.new': ('ml.mcd.html#mcddataloader.new', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataLoader.to': ('ml.mcd.html#mcddataloader.to', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataset': ('ml.mcd.html#mcddataset', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataset.__getitem__': ('ml.mcd.html#mcddataset.__getitem__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataset.__init__': ('ml.mcd.html#mcddataset.__init__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdDataset.__len__': ('ml.mcd.html#mcddataset.__len__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdModel': ('ml.mcd.html#mcdmodel', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdModel.__init__': ('ml.mcd.html#mcdmodel.__init__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.McdModel.forward': ('ml.mcd.html#mcdmodel.forward', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.Predictor': ('ml.mcd.html#predictor', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.Predictor.__init__': ('ml.mcd.html#predictor.__init__', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.Predictor.forward': ('ml.mcd.html#predictor.forward', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.discrepancy': ('ml.mcd.html#discrepancy', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.discrepancy_metric': ('ml.mcd.html#discrepancy_metric', 'bellek/ml/mcd.py'),
                               'bellek.ml.mcd.mcd_learner': ('ml.mcd.html#mcd_learner', 'bellek/ml/mcd.py')},
            'bellek.ml.transformers': { 'bellek.ml.transformers.load_tokenizer_model': ( 'ml.transformers.html#load_tokenizer_model',
                                                                                         'bellek/ml/transformers.py'),
                                        'bellek.ml.transformers.merge_adapters_and_publish': ( 'ml.transformers.html#merge_adapters_and_publish',
                                                                                               'bellek/ml/transformers.py'),
                                        'bellek.ml.transformers.preprocess_config': ( 'ml.transformers.html#preprocess_config',
                                                                                      'bellek/ml/transformers.py')},
            'bellek.ml.vision': { 'bellek.ml.vision.Make3Channel': ('ml.vision.html#make3channel', 'bellek/ml/vision.py'),
                                  'bellek.ml.vision.Make3Channel.__call__': ('ml.vision.html#make3channel.__call__', 'bellek/ml/vision.py'),
                                  'bellek.ml.vision.Make3Channel.__repr__': ('ml.vision.html#make3channel.__repr__', 'bellek/ml/vision.py'),
                                  'bellek.ml.vision.TorchVisionTransform': ('ml.vision.html#torchvisiontransform', 'bellek/ml/vision.py'),
                                  'bellek.ml.vision.TorchVisionTransform.__init__': ( 'ml.vision.html#torchvisiontransform.__init__',
                                                                                      'bellek/ml/vision.py'),
                                  'bellek.ml.vision.TorchVisionTransform.encodes': ( 'ml.vision.html#torchvisiontransform.encodes',
                                                                                     'bellek/ml/vision.py')},
            'bellek.ml.wandb': { 'bellek.ml.wandb.fetch_wandb_config': ('ml.wandb.html#fetch_wandb_config', 'bellek/ml/wandb.py'),
                                 'bellek.ml.wandb.fetch_wandb_run': ('ml.wandb.html#fetch_wandb_run', 'bellek/ml/wandb.py')},
            'bellek.testing': { 'bellek.testing.fixture_directory': ('testing.html#fixture_directory', 'bellek/testing.py'),
                                'bellek.testing.fixture_path': ('testing.html#fixture_path', 'bellek/testing.py')},
            'bellek.utils': { 'bellek.utils.NestedDict': ('utils.html#nesteddict', 'bellek/utils.py'),
                              'bellek.utils.NestedDict.__init__': ('utils.html#nesteddict.__init__', 'bellek/utils.py'),
                              'bellek.utils.NestedDict.at': ('utils.html#nesteddict.at', 'bellek/utils.py'),
                              'bellek.utils.NestedDict.flat': ('utils.html#nesteddict.flat', 'bellek/utils.py'),
                              'bellek.utils.NestedDict.from_flat_dict': ('utils.html#nesteddict.from_flat_dict', 'bellek/utils.py'),
                              'bellek.utils.NestedDict.set': ('utils.html#nesteddict.set', 'bellek/utils.py'),
                              'bellek.utils.Path.ls_sorted': ('utils.html#path.ls_sorted', 'bellek/utils.py'),
                              'bellek.utils.context_chdir': ('utils.html#context_chdir', 'bellek/utils.py'),
                              'bellek.utils.flatten_dict': ('utils.html#flatten_dict', 'bellek/utils.py'),
                              'bellek.utils.generate_time_id': ('utils.html#generate_time_id', 'bellek/utils.py'),
                              'bellek.utils.most_common': ('utils.html#most_common', 'bellek/utils.py'),
                              'bellek.utils.split_camel_case': ('utils.html#split_camel_case', 'bellek/utils.py'),
                              'bellek.utils.unflatten_dict': ('utils.html#unflatten_dict', 'bellek/utils.py')}}}
